@@ -15,6 +15,7 @@ import (
 	types "k8s.io/cri-api/pkg/apis/runtime/v1"
 	kubeletTypes "k8s.io/kubelet/pkg/types"
 
+	"github.com/cri-o/cri-o/internal/annotations"
 	"github.com/cri-o/cri-o/internal/config/capabilities"
 	"github.com/cri-o/cri-o/internal/hostport"
 	"github.com/cri-o/cri-o/internal/lib/constants"
@@ -23,7 +24,7 @@ import (
 	oci "github.com/cri-o/cri-o/internal/oci"
 	"github.com/cri-o/cri-o/internal/storage"
 	"github.com/cri-o/cri-o/internal/storage/references"
-	"github.com/cri-o/cri-o/pkg/annotations"
+	v2 "github.com/cri-o/cri-o/pkg/annotations/v2"
 	pkgConfig "github.com/cri-o/cri-o/pkg/config"
 )
 
@@ -359,7 +360,7 @@ var _ = t.Describe("Container", func() {
 			config.Labels = map[string]string{
 				kubeletTypes.KubernetesContainerNameLabel: containerName,
 			}
-			annotationKey := fmt.Sprintf("%s.%s", annotations.UnifiedCgroupAnnotation, containerName)
+			annotationKey := fmt.Sprintf("%s/%s", v2.UnifiedCgroup, containerName)
 			annotationsMap := map[string]string{
 				annotationKey: "memory.max=1000000;memory.min=MTAwMDA=;memory.low=20000",
 			}
@@ -384,7 +385,7 @@ var _ = t.Describe("Container", func() {
 			}
 
 			differentContainerName := "bar"
-			annotationKey := fmt.Sprintf("%s.%s", annotations.UnifiedCgroupAnnotation, differentContainerName)
+			annotationKey := fmt.Sprintf("%s/%s", v2.UnifiedCgroup, differentContainerName)
 			annotationsMap := map[string]string{
 				annotationKey: "memory.max=1000000;memory.min=MTAwMDA=;memory.low=20000",
 			}
