@@ -5,6 +5,7 @@ package oci
 import (
 	"context"
 	"os"
+	"os/exec"
 	"syscall"
 
 	types "k8s.io/cri-api/pkg/apis/runtime/v1"
@@ -40,3 +41,7 @@ func (c *Container) SetSeccompProfilePath(pp string) {
 func (c *Container) SeccompProfilePath() string {
 	return ""
 }
+
+// setSysProcAttr is a no-op on non-Linux platforms.
+func setSysProcAttr(_ *exec.Cmd, _ uintptr) {
+}
