@@ -5,13 +5,13 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/containers/image/v5/docker/reference"
-	istorage "github.com/containers/image/v5/storage"
-	"github.com/containers/image/v5/types"
-	cs "github.com/containers/storage"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	digest "github.com/opencontainers/go-digest"
+	"go.podman.io/image/v5/docker/reference"
+	istorage "go.podman.io/image/v5/storage"
+	"go.podman.io/image/v5/types"
+	cs "go.podman.io/storage"
 	"go.uber.org/mock/gomock"
 
 	"github.com/cri-o/cri-o/internal/mockutils"
@@ -67,8 +67,7 @@ var _ = t.Describe("Image", func() {
 				SystemRegistriesConfPath: t.MustTempFile("registries"),
 			},
 			ImageConfig: config.ImageConfig{
-				DefaultTransport:   "docker://",
-				InsecureRegistries: []string{},
+				DefaultTransport: "docker://",
 			},
 		}
 
@@ -104,8 +103,7 @@ var _ = t.Describe("Image", func() {
 					SystemRegistriesConfPath: "../../test/registries.conf",
 				},
 				ImageConfig: config.ImageConfig{
-					DefaultTransport:   "",
-					InsecureRegistries: []string{},
+					DefaultTransport: "",
 				},
 			}
 			imageService, err := storage.GetImageService(
@@ -283,8 +281,7 @@ var _ = t.Describe("Image", func() {
 			config := &config.Config{
 				SystemContext: ctx,
 				ImageConfig: config.ImageConfig{
-					DefaultTransport:   "",
-					InsecureRegistries: []string{},
+					DefaultTransport: "",
 				},
 			}
 			// Create an empty file for the registries config path
@@ -572,6 +569,11 @@ var _ = t.Describe("Image", func() {
 	})
 
 	t.Describe("PullImage", func() {
+		var graphRoot string
+		BeforeEach(func() {
+			graphRoot = t.MustTempDir("ociartifact")
+		})
+
 		It("should fail on invalid policy path", func() {
 			// Given
 			imageRef, err := references.ParseRegistryImageReferenceFromOutOfProcessData("localhost/busybox:latest")
@@ -590,7 +592,7 @@ var _ = t.Describe("Image", func() {
 		It("should fail on copy image", func() {
 			// Given
 			mockutils.InOrder(
-				storeMock.EXPECT().GraphRoot().Return(""),
+				storeMock.EXPECT().GraphRoot().Return(graphRoot),
 			)
 			imageRef, err := references.ParseRegistryImageReferenceFromOutOfProcessData("localhost/busybox:latest")
 			Expect(err).ToNot(HaveOccurred())
@@ -608,7 +610,7 @@ var _ = t.Describe("Image", func() {
 		It("should fail on canonical copy image", func() {
 			// Given
 			mockutils.InOrder(
-				storeMock.EXPECT().GraphRoot().Return(""),
+				storeMock.EXPECT().GraphRoot().Return(graphRoot),
 			)
 			imageRef, err := references.ParseRegistryImageReferenceFromOutOfProcessData("localhost/busybox@sha256:" + testSHA256)
 			Expect(err).ToNot(HaveOccurred())
@@ -626,7 +628,7 @@ var _ = t.Describe("Image", func() {
 		It("should fail on cancelled context", func() {
 			// Given
 			mockutils.InOrder(
-				storeMock.EXPECT().GraphRoot().Return(""),
+				storeMock.EXPECT().GraphRoot().Return(graphRoot),
 			)
 			imageRef, err := references.ParseRegistryImageReferenceFromOutOfProcessData("localhost/busybox:latest")
 			Expect(err).ToNot(HaveOccurred())
@@ -647,7 +649,7 @@ var _ = t.Describe("Image", func() {
 		It("should fail on timed out context", func() {
 			// Given
 			mockutils.InOrder(
-				storeMock.EXPECT().GraphRoot().Return(""),
+				storeMock.EXPECT().GraphRoot().Return(graphRoot),
 			)
 			imageRef, err := references.ParseRegistryImageReferenceFromOutOfProcessData("localhost/busybox:latest")
 			Expect(err).ToNot(HaveOccurred())
