@@ -7,12 +7,12 @@ import (
 	"path"
 	"path/filepath"
 
-	"github.com/containers/storage"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	"go.podman.io/storage"
 
 	"github.com/cri-o/cri-o/internal/config/cgmgr"
-	crioann "github.com/cri-o/cri-o/pkg/annotations"
+	v2 "github.com/cri-o/cri-o/pkg/annotations/v2"
 	"github.com/cri-o/cri-o/pkg/config"
 	"github.com/cri-o/cri-o/utils/cmdrunner"
 )
@@ -731,7 +731,7 @@ var _ = t.Describe("Config", func() {
 			// Given
 			sut.Runtimes[config.DefaultRuntime] = &config.RuntimeHandler{
 				RuntimePath:        validFilePath,
-				AllowedAnnotations: []string{crioann.DevicesAnnotation},
+				AllowedAnnotations: []string{v2.Devices},
 			}
 
 			// When
@@ -739,8 +739,8 @@ var _ = t.Describe("Config", func() {
 
 			// Then
 			Expect(err).ToNot(HaveOccurred())
-			Expect(sut.Runtimes[config.DefaultRuntime].AllowedAnnotations).To(ContainElement(crioann.DevicesAnnotation))
-			Expect(sut.Runtimes[config.DefaultRuntime].DisallowedAnnotations).NotTo(ContainElement(crioann.DevicesAnnotation))
+			Expect(sut.Runtimes[config.DefaultRuntime].AllowedAnnotations).To(ContainElement(v2.Devices))
+			Expect(sut.Runtimes[config.DefaultRuntime].DisallowedAnnotations).NotTo(ContainElement(v2.Devices))
 		})
 
 		It("should allow no_sync_log for implicit default runtime", func() {
@@ -1780,4 +1780,168 @@ var _ = t.Describe("Config", func() {
 			Expect(ok).To(BeTrue())
 		})
 	})
+
+	t.Describe("ValidateContainerCreateTimeout", func() {
+		It("should set default timeout when not configured", func() {
+			// Given
+			handler := &config.RuntimeHandler{}
+
+			// When
+			handler.ValidateContainerCreateTimeout("test-runtime")
+
+			// Then
+			Expect(handler.ContainerCreateTimeout).To(Equal(int64(240)))
+		})
+
+		It("should use configured timeout when valid", func() {
+			// Given
+			handler := &config.RuntimeHandler{
+				ContainerCreateTimeout: 600, // 10 minutes
+			}
+
+			// When
+			handler.ValidateContainerCreateTimeout("test-runtime")
+
+			// Then
+			Expect(handler.ContainerCreateTimeout).To(Equal(int64(600)))
+		})
+
+		It("should set minimum timeout when below minimum", func() {
+			// Given
+			handler := &config.RuntimeHandler{
+				ContainerCreateTimeout: 15, // Below minimum of 30
+			}
+
+			// When
+			handler.ValidateContainerCreateTimeout("test-runtime")
+
+			// Then
+			Expect(handler.ContainerCreateTimeout).To(Equal(int64(30)))
+		})
+
+		It("should allow minimum timeout", func() {
+			// Given
+			handler := &config.RuntimeHandler{
+				ContainerCreateTimeout: 30, // Exactly minimum
+			}
+
+			// When
+			handler.ValidateContainerCreateTimeout("test-runtime")
+
+			// Then
+			Expect(handler.ContainerCreateTimeout).To(Equal(int64(30)))
+		})
+
+		It("should handle zero timeout by setting default", func() {
+			// Given
+			handler := &config.RuntimeHandler{
+				ContainerCreateTimeout: 0,
+			}
+
+			// When
+			handler.ValidateContainerCreateTimeout("test-runtime")
+
+			// Then
+			Expect(handler.ContainerCreateTimeout).To(Equal(int64(240)))
+		})
+
+		It("should handle negative timeout by setting minimum", func() {
+			// Given
+			handler := &config.RuntimeHandler{
+				ContainerCreateTimeout: -10,
+			}
+
+			// When
+			handler.ValidateContainerCreateTimeout("test-runtime")
+
+			// Then
+			Expect(handler.ContainerCreateTimeout).To(Equal(int64(30)))
+		})
+
+		It("should set different timeouts for different runtime handlers", func() {
+			// Given
+			sut.Runtimes[config.DefaultRuntime] = &config.RuntimeHandler{
+				RuntimePath:            validFilePath,
+				ContainerCreateTimeout: 300, // 5 minutes for OCI runtime
+			}
+			sut.Runtimes["kata"] = &config.RuntimeHandler{
+				RuntimePath:            validFilePath,
+				ContainerCreateTimeout: 600, // 10 minutes for VM runtime
+			}
+
+			// When
+			err := sut.ValidateRuntimes()
+
+			// Then
+			Expect(err).ToNot(HaveOccurred())
+			Expect(sut.Runtimes[config.DefaultRuntime].ContainerCreateTimeout).To(Equal(int64(300)))
+			Expect(sut.Runtimes["kata"].ContainerCreateTimeout).To(Equal(int64(600)))
+		})
+	})
+
+	t.Describe("StatsConfig.Validate", func() {
+		It("should succeed with default config", func() {
+			// Given
+			// When
+			err := sut.StatsConfig.Validate()
+
+			// Then
+			Expect(err).NotTo(HaveOccurred())
+		})
+
+		It("should succeed with valid config", func() {
+			// Given
+			sut.IncludedPodMetrics = []string{"cpu", "memory"}
+
+			// When
+			err := sut.StatsConfig.Validate()
+
+			// Then
+			Expect(err).NotTo(HaveOccurred())
+		})
+
+		It("should succeed with all", func() {
+			// Given
+			sut.IncludedPodMetrics = []string{"all"}
+
+			// When
+			err := sut.StatsConfig.Validate()
+
+			// Then
+			Expect(err).NotTo(HaveOccurred())
+		})
+
+		It("should fail with invalid metric", func() {
+			// Given
+			sut.IncludedPodMetrics = []string{"invalid"}
+
+			// When
+			err := sut.StatsConfig.Validate()
+
+			// Then
+			Expect(err).To(HaveOccurred())
+		})
+
+		It("should fail when all not in the first element", func() {
+			// Given
+			sut.IncludedPodMetrics = []string{"cpu", "memory", "all"}
+
+			// When
+			err := sut.StatsConfig.Validate()
+
+			// Then
+			Expect(err).To(HaveOccurred())
+		})
+
+		It("should fail when all is not the only one element", func() {
+			// Given
+			sut.IncludedPodMetrics = []string{"all", "cpu", "memory"}
+
+			// When
+			err := sut.StatsConfig.Validate()
+
+			// Then
+			Expect(err).To(HaveOccurred())
+		})
+	})
 })
