@@ -1,5 +1,4 @@
 //go:build test
-// +build test
 
 // All *_inject.go files are meant to be used by tests only. Purpose of this
 // files is to provide a way to inject mocked data into the current setup.
@@ -9,6 +8,7 @@ package config
 import (
 	"github.com/cri-o/ocicni/pkg/ocicni"
 
+	"github.com/cri-o/cri-o/internal/config/cgmgr"
 	"github.com/cri-o/cri-o/internal/config/cnimgr"
 	"github.com/cri-o/cri-o/internal/config/nsmgr"
 )
@@ -19,6 +19,7 @@ func (c *Config) SetCNIPlugin(plugin ocicni.CNIPlugin) error {
 	if c.cniManager == nil {
 		c.cniManager = &cnimgr.CNIManager{}
 	}
+
 	return c.cniManager.SetCNIPlugin(plugin)
 }
 
@@ -32,3 +33,8 @@ func (c *Config) SetNamespaceManager(nsMgr *nsmgr.NamespaceManager) {
 func (c *RuntimeConfig) SetCheckpointRestore(cr bool) {
 	c.EnableCriuSupport = cr
 }
+
+// SetCgroupManager sets the cgroupManager for the RuntimeConfig.
+func (c *RuntimeConfig) SetCgroupManager(mgr cgmgr.CgroupManager) {
+	c.cgroupManager = mgr
+}
