@@ -25,10 +25,10 @@ var _ = t.Describe("Version", func() {
 			// Then
 			Expect(err).ToNot(HaveOccurred())
 			Expect(response).NotTo(BeNil())
-			Expect(response.Version).NotTo(BeEmpty())
-			Expect(response.RuntimeName).NotTo(BeEmpty())
-			Expect(response.RuntimeName).NotTo(BeEmpty())
-			Expect(response.RuntimeApiVersion).To(Equal("v1"))
+			Expect(response.GetVersion()).NotTo(BeEmpty())
+			Expect(response.GetRuntimeName()).NotTo(BeEmpty())
+			Expect(response.GetRuntimeName()).NotTo(BeEmpty())
+			Expect(response.GetRuntimeApiVersion()).To(Equal("v1"))
 		})
 	})
 })
