@@ -4,6 +4,8 @@ import (
 	"context"
 	"flag"
 	"fmt"
+	"maps"
+	"slices"
 	"sync"
 	"time"
 
@@ -21,6 +23,7 @@ const (
 
 type runtime struct {
 	sync.Mutex
+
 	cc         *grpc.ClientConn
 	runtime    cri.RuntimeServiceClient
 	image      cri.ImageServiceClient
@@ -47,12 +50,11 @@ func ConnectRuntime() (*runtime, error) {
 
 	dialOpts := []grpc.DialOption{
 		grpc.WithTransportCredentials(insecure.NewCredentials()),
-		grpc.WithBlock(),                  //nolint:staticcheck // use it until an appropriate alternative is present
-		grpc.FailOnNonTempDialError(true), //nolint:staticcheck // use it until an appropriate alternative is present
+		grpc.WithBlock(),                  //nolint:staticcheck,nolintlint
+		grpc.FailOnNonTempDialError(true), //nolint:staticcheck,nolintlint
 	}
 
-	//nolint:staticcheck // use it until an appropriate alternative is present
-	cc, err := grpc.DialContext(ctx, *crioSocket, dialOpts...)
+	cc, err := grpc.DialContext(ctx, *crioSocket, dialOpts...) //nolint:staticcheck,nolintlint
 	if err != nil {
 		return nil, fmt.Errorf("runtime connection failed: %w", err)
 	}
@@ -119,10 +121,8 @@ func (r *runtime) PullImage(image string) (string, error) {
 	}
 
 	for _, img := range listReply.GetImages() {
-		for _, tag := range img.GetRepoTags() {
-			if tag == image {
-				return img.GetId(), nil
-			}
+		if slices.Contains(img.GetRepoTags(), image) {
+			return img.GetId(), nil
 		}
 	}
 
@@ -167,9 +167,7 @@ type PodOption func(*cri.PodSandboxConfig) error
 
 func WithPodAnnotations(annotations map[string]string) PodOption {
 	return func(cfg *cri.PodSandboxConfig) error {
-		for k, v := range annotations {
-			cfg.Annotations[k] = v
-		}
+		maps.Copy(cfg.GetAnnotations(), annotations)
 
 		return nil
 	}
@@ -177,9 +175,7 @@ func WithPodAnnotations(annotations map[string]string) PodOption {
 
 func WithPodLabels(labels map[string]string) PodOption {
 	return func(cfg *cri.PodSandboxConfig) error {
-		for k, v := range labels {
-			cfg.Labels[k] = v
-		}
+		maps.Copy(cfg.GetLabels(), labels)
 
 		return nil
 	}
@@ -405,9 +401,7 @@ func WithEnv(envs []*cri.KeyValue) ContainerOption {
 
 func WithAnnotations(annotations map[string]string) ContainerOption {
 	return func(cfg *cri.ContainerConfig) error {
-		for k, v := range annotations {
-			cfg.Annotations[k] = v
-		}
+		maps.Copy(cfg.GetAnnotations(), annotations)
 
 		return nil
 	}
@@ -415,9 +409,7 @@ func WithAnnotations(annotations map[string]string) ContainerOption {
 
 func WithLabels(labels map[string]string) ContainerOption {
 	return func(cfg *cri.ContainerConfig) error {
-		for k, v := range labels {
-			cfg.Labels[k] = v
-		}
+		maps.Copy(cfg.GetLabels(), labels)
 
 		return nil
 	}
